@@ -13,6 +13,7 @@ from flask import (
     request,
     Blueprint,
     current_app,
+    session,
 )
 
 
@@ -21,8 +22,16 @@ bp = Blueprint("contact", __name__)
 
 @bp.route("/contact", methods=["POST"])
 def contact():
+    form_data = request.form
+
+    try:
+        if form_data["captcha"] != session["captcha"]:
+            return dict(error="Bad Captcha."), 404
+    except KeyError:
+        return dict(error="Bad Captcha."), 404
+
     response = requests.post(
         url="{}contact".format(current_app.config["SERVER_API_BASE_URL"]),
-        data=request.form,
+        data=form_data,
     )
     return response.text, response.status_code
