@@ -8,6 +8,7 @@ __maintainer__ = "Paulo Antunes"
 __email__ = "pjmlantunes@gmail.com"
 
 
+from mongoengine import Q
 from mongoengine.errors import ValidationError
 from xtcryptosignals.server.api.projects.models import Project
 from xtcryptosignals.tasks.models.project_twitter import ProjectTwitter
@@ -19,7 +20,9 @@ def projects():
 
 def project_twitter(project):
     try:
-        row = ProjectTwitter.objects(project=project).first()
+        row = ProjectTwitter.objects(
+            Q(project=project) & Q(num_followers__exists=True)
+        ).first()
         if not row:
             raise ValueError("Project does not exist or no twitter data", 404)
     except ValidationError:
