@@ -39,7 +39,13 @@ class Transaction(DocumentValidation):
     )
     user = ReferenceField(User, required=True)
     added_on = DateField(required=True)
-    in_or_out = StringField(required=True, choices=("in", "out",))
+    in_or_out = StringField(
+        required=True,
+        choices=(
+            "in",
+            "out",
+        ),
+    )
 
     meta = {
         "collection": "transaction",
