@@ -24,27 +24,24 @@ class Config(object):
     TESTING = False
 
     BROKER_URL = "redis://localhost:6379"
+    SESSION_REDIS = Redis.from_url(BROKER_URL)
 
     SESSION_TYPE = "redis"
 
-    SESSION_REDIS = Redis.from_url(BROKER_URL)
-
     SECRET_KEY = None
 
     CORS_ALLOWED_ORIGINS = None
 
+    SWAGGER = None
+
 
 class ConfigProduction(Config):
     DEBUG = False
 
-    SESSION_COOKIE_SECURE = True
-
 
 class ConfigDevelopment(Config):
     DEBUG = True
 
-    SESSION_COOKIE_SECURE = False
-
     SWAGGER = {
         "info": {
             "title": __title__,
@@ -69,3 +66,4 @@ class ConfigDevelopment(Config):
 
 class ConfigDocker(ConfigDevelopment):
     BROKER_URL = "redis://172.19.10.6:6379"
+    SESSION_REDIS = Redis.from_url(BROKER_URL)
