@@ -58,12 +58,17 @@ from xtcryptosignals.settings_exchanges import (
     BITSTAMP,
     KUCOIN,
     COINBASE_PRO,
+    LIQUID,
 )  # noqa
 
 __all__ = [
     "EXCHANGES",
     "SYMBOLS_PER_EXCHANGE",
     "EXCHANGES_AND_PAIRS_OF_REFERENCE",
+    "TICKER_SCHEDULE",
+    "HISTORY_FREQUENCY",
+    "PRICE_CHANGE_FREQUENCIES",
+    # exchanges
     "BINANCE",
     "BINANCE_DEX",
     "UPHOLD",
@@ -81,7 +86,5 @@ __all__ = [
     "BITSTAMP",
     "KUCOIN",
     "COINBASE_PRO",
-    "TICKER_SCHEDULE",
-    "HISTORY_FREQUENCY",
-    "PRICE_CHANGE_FREQUENCIES",
+    "LIQUID",
 ]
