@@ -15,7 +15,11 @@ from billiard.context import Process
 from flask_socketio import SocketIO
 from xtcryptosignals.tasks.celeryconfig import BROKER_URL
 from binance.client import Client as BinanceClient
-from idex.client import Client as IdexClient
+
+try:
+    from idex.client import Client as IdexClient
+except ModuleNotFoundError:
+    pass
 from xtcryptosignals.tasks.utils import terminate_running_jobs
 from xtcryptosignals.tasks import settings as s
 
@@ -143,7 +147,13 @@ def update(self):
                 p = Process(
                     name=f"{coin_or_token}-{quote}",
                     target=_method,
-                    args=(logger, (coin_or_token, quote,),),
+                    args=(
+                        logger,
+                        (
+                            coin_or_token,
+                            quote,
+                        ),
+                    ),
                 )
                 jobs.append(dict(job=p, timeout=s.TIMEOUT_ORDER_BOOK))
                 p.start()
