@@ -82,7 +82,14 @@ def _get_24h_price_ticker_data(
     p = Process(
         name="{} {}".format(exchange_class.__name__, symbol_or_pairs),
         target=_process,
-        args=(logger, socketio, exchange_class, schema_class, symbol, pairs,),
+        args=(
+            logger,
+            socketio,
+            exchange_class,
+            schema_class,
+            symbol,
+            pairs,
+        ),
     )
     jobs.append(
         dict(
@@ -163,7 +170,8 @@ def update(self, *_, **kwargs):
 
 def test(*_, **kwargs):
     logging.basicConfig(
-        format="%(asctime)s %(levelname)s %(message)s", level=logging.INFO,
+        format="%(asctime)s %(levelname)s %(message)s",
+        level=logging.INFO,
     )
     logging.info("Process 1 Tick")
     logging.info("Starting...")
